pub struct MerkleProof {
pub siblings: Vec<SiblingNode>,
}Expand description
A Merkle path proving that one leaf belongs to a tree.
Fields
siblings: Vec<SiblingNode>Implementations
Sourceimpl MerkleProof
impl MerkleProof
Sourcepub fn verify(&self, leaf: &IntentHash, expected_root: &IntentHash) -> bool
pub fn verify(&self, leaf: &IntentHash, expected_root: &IntentHash) -> bool
Recompute the root from leaf along this proof path and return whether
it equals expected_root.